# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/kafka/v1/connector.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/kafka/v1/connector.proto',
  package='yandex.cloud.mdb.kafka.v1',
  syntax='proto3',
  serialized_options=b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)yandex/cloud/mdb/kafka/v1/connector.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1egoogle/protobuf/wrappers.proto\"\xc5\x02\n\rConnectorSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ttasks_max\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\nproperties\x18\x03 \x03(\x0b\x32\x38.yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry\x12\x61\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x39.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpecH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10\x63onnector_config\"\xc3\x02\n\x13UpdateConnectorSpec\x12.\n\ttasks_max\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12R\n\nproperties\x18\x02 \x03(\x0b\x32>.yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry\x12\x61\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x39.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpecH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10\x63onnector_config\"\xfd\x01\n\x1e\x43onnectorConfigMirrorMakerSpec\x12H\n\x0esource_cluster\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec\x12H\n\x0etarget_cluster\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec\x12\x0e\n\x06topics\x18\x03 \x01(\t\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xd6\x01\n\x15\x43lusterConnectionSpec\x12\r\n\x05\x61lias\x18\x01 \x01(\t\x12\x42\n\x0cthis_cluster\x18\x02 \x01(\x0b\x32*.yandex.cloud.mdb.kafka.v1.ThisClusterSpecH\x00\x12T\n\x10\x65xternal_cluster\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpecH\x00\x42\x14\n\x12\x63luster_connection\"\x11\n\x0fThisClusterSpec\"\xc0\x01\n\x1d\x45xternalClusterConnectionSpec\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\x15\n\rsasl_username\x18\x02 \x01(\t\x12\x15\n\rsasl_password\x18\x03 \x01(\t\x12\x16\n\x0esasl_mechanism\x18\x04 \x01(\t\x12\x19\n\x11security_protocol\x18\x05 \x01(\t\x12#\n\x1bssl_truststore_certificates\x18\x06 \x01(\t\"\xbc\x04\n\tConnector\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\ttasks_max\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12H\n\nproperties\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry\x12;\n\x06health\x18\x04 \x01(\x0e\x32+.yandex.cloud.mdb.kafka.v1.Connector.Health\x12;\n\x06status\x18\x05 \x01(\x0e\x32+.yandex.cloud.mdb.kafka.v1.Connector.Status\x12\x12\n\ncluster_id\x18\x06 \x01(\t\x12]\n\x1c\x63onnector_config_mirrormaker\x18\n \x01(\x0b\x32\x35.yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"@\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\n\n\x06PAUSED\x10\x03\x42\x12\n\x10\x63onnector_config\"\xf1\x01\n\x1a\x43onnectorConfigMirrorMaker\x12\x44\n\x0esource_cluster\x18\x01 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ClusterConnection\x12\x44\n\x0etarget_cluster\x18\x02 \x01(\x0b\x32,.yandex.cloud.mdb.kafka.v1.ClusterConnection\x12\x0e\n\x06topics\x18\x03 \x01(\t\x12\x37\n\x12replication_factor\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xca\x01\n\x11\x43lusterConnection\x12\r\n\x05\x61lias\x18\x01 \x01(\t\x12>\n\x0cthis_cluster\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.kafka.v1.ThisClusterH\x00\x12P\n\x10\x65xternal_cluster\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionH\x00\x42\x14\n\x12\x63luster_connection\"\r\n\x0bThisCluster\"\x80\x01\n\x19\x45xternalClusterConnection\x12\x19\n\x11\x62ootstrap_servers\x18\x01 \x01(\t\x12\x15\n\rsasl_username\x18\x02 \x01(\t\x12\x16\n\x0esasl_mechanism\x18\x04 \x01(\t\x12\x19\n\x11security_protocol\x18\x05 \x01(\tBd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])



_CONNECTOR_HEALTH = _descriptor.EnumDescriptor(
  name='Health',
  full_name='yandex.cloud.mdb.kafka.v1.Connector.Health',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HEALTH_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1883,
  serialized_end=1932,
)
_sym_db.RegisterEnumDescriptor(_CONNECTOR_HEALTH)

_CONNECTOR_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.mdb.kafka.v1.Connector.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1934,
  serialized_end=1998,
)
_sym_db.RegisterEnumDescriptor(_CONNECTOR_STATUS)


_CONNECTORSPEC_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=410,
)

_CONNECTORSPEC = _descriptor.Descriptor(
  name='ConnectorSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks_max', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.tasks_max', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connector_config_mirrormaker', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.connector_config_mirrormaker', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONNECTORSPEC_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connector_config', full_name='yandex.cloud.mdb.kafka.v1.ConnectorSpec.connector_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=105,
  serialized_end=430,
)


_UPDATECONNECTORSPEC_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=410,
)

_UPDATECONNECTORSPEC = _descriptor.Descriptor(
  name='UpdateConnectorSpec',
  full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tasks_max', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.tasks_max', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connector_config_mirrormaker', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.connector_config_mirrormaker', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATECONNECTORSPEC_PROPERTIESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connector_config', full_name='yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.connector_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=433,
  serialized_end=756,
)


_CONNECTORCONFIGMIRRORMAKERSPEC = _descriptor.Descriptor(
  name='ConnectorConfigMirrorMakerSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_cluster', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec.source_cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_cluster', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec.target_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec.topics', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replication_factor', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec.replication_factor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=1012,
)


_CLUSTERCONNECTIONSPEC = _descriptor.Descriptor(
  name='ClusterConnectionSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alias', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec.alias', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='this_cluster', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec.this_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_cluster', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec.external_cluster', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_connection', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec.cluster_connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1015,
  serialized_end=1229,
)


_THISCLUSTERSPEC = _descriptor.Descriptor(
  name='ThisClusterSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ThisClusterSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1231,
  serialized_end=1248,
)


_EXTERNALCLUSTERCONNECTIONSPEC = _descriptor.Descriptor(
  name='ExternalClusterConnectionSpec',
  full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bootstrap_servers', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.bootstrap_servers', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_username', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.sasl_username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_password', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.sasl_password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_mechanism', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.sasl_mechanism', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_protocol', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.security_protocol', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssl_truststore_certificates', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec.ssl_truststore_certificates', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1443,
)


_CONNECTOR_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=410,
)

_CONNECTOR = _descriptor.Descriptor(
  name='Connector',
  full_name='yandex.cloud.mdb.kafka.v1.Connector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.mdb.kafka.v1.Connector.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks_max', full_name='yandex.cloud.mdb.kafka.v1.Connector.tasks_max', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='properties', full_name='yandex.cloud.mdb.kafka.v1.Connector.properties', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='health', full_name='yandex.cloud.mdb.kafka.v1.Connector.health', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.mdb.kafka.v1.Connector.status', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_id', full_name='yandex.cloud.mdb.kafka.v1.Connector.cluster_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connector_config_mirrormaker', full_name='yandex.cloud.mdb.kafka.v1.Connector.connector_config_mirrormaker', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONNECTOR_PROPERTIESENTRY, ],
  enum_types=[
    _CONNECTOR_HEALTH,
    _CONNECTOR_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='connector_config', full_name='yandex.cloud.mdb.kafka.v1.Connector.connector_config',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1446,
  serialized_end=2018,
)


_CONNECTORCONFIGMIRRORMAKER = _descriptor.Descriptor(
  name='ConnectorConfigMirrorMaker',
  full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_cluster', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker.source_cluster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_cluster', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker.target_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topics', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker.topics', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replication_factor', full_name='yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker.replication_factor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2021,
  serialized_end=2262,
)


_CLUSTERCONNECTION = _descriptor.Descriptor(
  name='ClusterConnection',
  full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alias', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection.alias', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='this_cluster', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection.this_cluster', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_cluster', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection.external_cluster', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cluster_connection', full_name='yandex.cloud.mdb.kafka.v1.ClusterConnection.cluster_connection',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2265,
  serialized_end=2467,
)


_THISCLUSTER = _descriptor.Descriptor(
  name='ThisCluster',
  full_name='yandex.cloud.mdb.kafka.v1.ThisCluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2469,
  serialized_end=2482,
)


_EXTERNALCLUSTERCONNECTION = _descriptor.Descriptor(
  name='ExternalClusterConnection',
  full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bootstrap_servers', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection.bootstrap_servers', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_username', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection.sasl_username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sasl_mechanism', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection.sasl_mechanism', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_protocol', full_name='yandex.cloud.mdb.kafka.v1.ExternalClusterConnection.security_protocol', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2485,
  serialized_end=2613,
)

_CONNECTORSPEC_PROPERTIESENTRY.containing_type = _CONNECTORSPEC
_CONNECTORSPEC.fields_by_name['tasks_max'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONNECTORSPEC.fields_by_name['properties'].message_type = _CONNECTORSPEC_PROPERTIESENTRY
_CONNECTORSPEC.fields_by_name['connector_config_mirrormaker'].message_type = _CONNECTORCONFIGMIRRORMAKERSPEC
_CONNECTORSPEC.oneofs_by_name['connector_config'].fields.append(
  _CONNECTORSPEC.fields_by_name['connector_config_mirrormaker'])
_CONNECTORSPEC.fields_by_name['connector_config_mirrormaker'].containing_oneof = _CONNECTORSPEC.oneofs_by_name['connector_config']
_UPDATECONNECTORSPEC_PROPERTIESENTRY.containing_type = _UPDATECONNECTORSPEC
_UPDATECONNECTORSPEC.fields_by_name['tasks_max'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_UPDATECONNECTORSPEC.fields_by_name['properties'].message_type = _UPDATECONNECTORSPEC_PROPERTIESENTRY
_UPDATECONNECTORSPEC.fields_by_name['connector_config_mirrormaker'].message_type = _CONNECTORCONFIGMIRRORMAKERSPEC
_UPDATECONNECTORSPEC.oneofs_by_name['connector_config'].fields.append(
  _UPDATECONNECTORSPEC.fields_by_name['connector_config_mirrormaker'])
_UPDATECONNECTORSPEC.fields_by_name['connector_config_mirrormaker'].containing_oneof = _UPDATECONNECTORSPEC.oneofs_by_name['connector_config']
_CONNECTORCONFIGMIRRORMAKERSPEC.fields_by_name['source_cluster'].message_type = _CLUSTERCONNECTIONSPEC
_CONNECTORCONFIGMIRRORMAKERSPEC.fields_by_name['target_cluster'].message_type = _CLUSTERCONNECTIONSPEC
_CONNECTORCONFIGMIRRORMAKERSPEC.fields_by_name['replication_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CLUSTERCONNECTIONSPEC.fields_by_name['this_cluster'].message_type = _THISCLUSTERSPEC
_CLUSTERCONNECTIONSPEC.fields_by_name['external_cluster'].message_type = _EXTERNALCLUSTERCONNECTIONSPEC
_CLUSTERCONNECTIONSPEC.oneofs_by_name['cluster_connection'].fields.append(
  _CLUSTERCONNECTIONSPEC.fields_by_name['this_cluster'])
_CLUSTERCONNECTIONSPEC.fields_by_name['this_cluster'].containing_oneof = _CLUSTERCONNECTIONSPEC.oneofs_by_name['cluster_connection']
_CLUSTERCONNECTIONSPEC.oneofs_by_name['cluster_connection'].fields.append(
  _CLUSTERCONNECTIONSPEC.fields_by_name['external_cluster'])
_CLUSTERCONNECTIONSPEC.fields_by_name['external_cluster'].containing_oneof = _CLUSTERCONNECTIONSPEC.oneofs_by_name['cluster_connection']
_CONNECTOR_PROPERTIESENTRY.containing_type = _CONNECTOR
_CONNECTOR.fields_by_name['tasks_max'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CONNECTOR.fields_by_name['properties'].message_type = _CONNECTOR_PROPERTIESENTRY
_CONNECTOR.fields_by_name['health'].enum_type = _CONNECTOR_HEALTH
_CONNECTOR.fields_by_name['status'].enum_type = _CONNECTOR_STATUS
_CONNECTOR.fields_by_name['connector_config_mirrormaker'].message_type = _CONNECTORCONFIGMIRRORMAKER
_CONNECTOR_HEALTH.containing_type = _CONNECTOR
_CONNECTOR_STATUS.containing_type = _CONNECTOR
_CONNECTOR.oneofs_by_name['connector_config'].fields.append(
  _CONNECTOR.fields_by_name['connector_config_mirrormaker'])
_CONNECTOR.fields_by_name['connector_config_mirrormaker'].containing_oneof = _CONNECTOR.oneofs_by_name['connector_config']
_CONNECTORCONFIGMIRRORMAKER.fields_by_name['source_cluster'].message_type = _CLUSTERCONNECTION
_CONNECTORCONFIGMIRRORMAKER.fields_by_name['target_cluster'].message_type = _CLUSTERCONNECTION
_CONNECTORCONFIGMIRRORMAKER.fields_by_name['replication_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CLUSTERCONNECTION.fields_by_name['this_cluster'].message_type = _THISCLUSTER
_CLUSTERCONNECTION.fields_by_name['external_cluster'].message_type = _EXTERNALCLUSTERCONNECTION
_CLUSTERCONNECTION.oneofs_by_name['cluster_connection'].fields.append(
  _CLUSTERCONNECTION.fields_by_name['this_cluster'])
_CLUSTERCONNECTION.fields_by_name['this_cluster'].containing_oneof = _CLUSTERCONNECTION.oneofs_by_name['cluster_connection']
_CLUSTERCONNECTION.oneofs_by_name['cluster_connection'].fields.append(
  _CLUSTERCONNECTION.fields_by_name['external_cluster'])
_CLUSTERCONNECTION.fields_by_name['external_cluster'].containing_oneof = _CLUSTERCONNECTION.oneofs_by_name['cluster_connection']
DESCRIPTOR.message_types_by_name['ConnectorSpec'] = _CONNECTORSPEC
DESCRIPTOR.message_types_by_name['UpdateConnectorSpec'] = _UPDATECONNECTORSPEC
DESCRIPTOR.message_types_by_name['ConnectorConfigMirrorMakerSpec'] = _CONNECTORCONFIGMIRRORMAKERSPEC
DESCRIPTOR.message_types_by_name['ClusterConnectionSpec'] = _CLUSTERCONNECTIONSPEC
DESCRIPTOR.message_types_by_name['ThisClusterSpec'] = _THISCLUSTERSPEC
DESCRIPTOR.message_types_by_name['ExternalClusterConnectionSpec'] = _EXTERNALCLUSTERCONNECTIONSPEC
DESCRIPTOR.message_types_by_name['Connector'] = _CONNECTOR
DESCRIPTOR.message_types_by_name['ConnectorConfigMirrorMaker'] = _CONNECTORCONFIGMIRRORMAKER
DESCRIPTOR.message_types_by_name['ClusterConnection'] = _CLUSTERCONNECTION
DESCRIPTOR.message_types_by_name['ThisCluster'] = _THISCLUSTER
DESCRIPTOR.message_types_by_name['ExternalClusterConnection'] = _EXTERNALCLUSTERCONNECTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConnectorSpec = _reflection.GeneratedProtocolMessageType('ConnectorSpec', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONNECTORSPEC_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ConnectorSpec.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _CONNECTORSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ConnectorSpec)
  })
_sym_db.RegisterMessage(ConnectorSpec)
_sym_db.RegisterMessage(ConnectorSpec.PropertiesEntry)

UpdateConnectorSpec = _reflection.GeneratedProtocolMessageType('UpdateConnectorSpec', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECONNECTORSPEC_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECONNECTORSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.UpdateConnectorSpec)
  })
_sym_db.RegisterMessage(UpdateConnectorSpec)
_sym_db.RegisterMessage(UpdateConnectorSpec.PropertiesEntry)

ConnectorConfigMirrorMakerSpec = _reflection.GeneratedProtocolMessageType('ConnectorConfigMirrorMakerSpec', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORCONFIGMIRRORMAKERSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMakerSpec)
  })
_sym_db.RegisterMessage(ConnectorConfigMirrorMakerSpec)

ClusterConnectionSpec = _reflection.GeneratedProtocolMessageType('ClusterConnectionSpec', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONNECTIONSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ClusterConnectionSpec)
  })
_sym_db.RegisterMessage(ClusterConnectionSpec)

ThisClusterSpec = _reflection.GeneratedProtocolMessageType('ThisClusterSpec', (_message.Message,), {
  'DESCRIPTOR' : _THISCLUSTERSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ThisClusterSpec)
  })
_sym_db.RegisterMessage(ThisClusterSpec)

ExternalClusterConnectionSpec = _reflection.GeneratedProtocolMessageType('ExternalClusterConnectionSpec', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALCLUSTERCONNECTIONSPEC,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ExternalClusterConnectionSpec)
  })
_sym_db.RegisterMessage(ExternalClusterConnectionSpec)

Connector = _reflection.GeneratedProtocolMessageType('Connector', (_message.Message,), {

  'PropertiesEntry' : _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONNECTOR_PROPERTIESENTRY,
    '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.Connector.PropertiesEntry)
    })
  ,
  'DESCRIPTOR' : _CONNECTOR,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.Connector)
  })
_sym_db.RegisterMessage(Connector)
_sym_db.RegisterMessage(Connector.PropertiesEntry)

ConnectorConfigMirrorMaker = _reflection.GeneratedProtocolMessageType('ConnectorConfigMirrorMaker', (_message.Message,), {
  'DESCRIPTOR' : _CONNECTORCONFIGMIRRORMAKER,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ConnectorConfigMirrorMaker)
  })
_sym_db.RegisterMessage(ConnectorConfigMirrorMaker)

ClusterConnection = _reflection.GeneratedProtocolMessageType('ClusterConnection', (_message.Message,), {
  'DESCRIPTOR' : _CLUSTERCONNECTION,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ClusterConnection)
  })
_sym_db.RegisterMessage(ClusterConnection)

ThisCluster = _reflection.GeneratedProtocolMessageType('ThisCluster', (_message.Message,), {
  'DESCRIPTOR' : _THISCLUSTER,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ThisCluster)
  })
_sym_db.RegisterMessage(ThisCluster)

ExternalClusterConnection = _reflection.GeneratedProtocolMessageType('ExternalClusterConnection', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALCLUSTERCONNECTION,
  '__module__' : 'yandex.cloud.mdb.kafka.v1.connector_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.kafka.v1.ExternalClusterConnection)
  })
_sym_db.RegisterMessage(ExternalClusterConnection)


DESCRIPTOR._options = None
_CONNECTORSPEC_PROPERTIESENTRY._options = None
_UPDATECONNECTORSPEC_PROPERTIESENTRY._options = None
_CONNECTOR_PROPERTIESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/disk_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import disk_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/disk_service.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*yandex/cloud/compute/v1/disk_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/compute/v1/disk.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"/\n\x0eGetDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8d\x01\n\x10ListDisksRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"Z\n\x11ListDisksResponse\x12,\n\x05\x64isks\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.compute.v1.Disk\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdb\x04\n\x11\x43reateDiskRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x19\n\x07type_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\x07zone_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x04size\x18\x07 \x01(\x03\x42\x1e\xe8\xc7\x31\x01\xfa\xc7\x31\x16\x34\x31\x39\x34\x33\x30\x34-28587302322176\x12\x1c\n\x08image_id\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x12\n\nblock_size\x18\n \x01(\x03\x12K\n\x15\x64isk_placement_policy\x18\x0b \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06source\"%\n\x12\x43reateDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\"\xee\x03\n\x11UpdateDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8f\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x36.yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\'\n\x04size\x18\x06 \x01(\x03\x42\x19\xfa\xc7\x31\x15\x34\x31\x39\x34\x33\x30\x34-4398046511104\x12K\n\x15\x64isk_placement_policy\x18\x07 \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"%\n\x12UpdateDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\"2\n\x11\x44\x65leteDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"%\n\x12\x44\x65leteDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\"x\n\x19ListDiskOperationsRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x1aListDiskOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"]\n\x0fMoveDiskRequest\x12\x1d\n\x07\x64isk_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\\\n\x10MoveDiskMetadata\x12\x0f\n\x07\x64isk_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t2\xaa\x08\n\x0b\x44iskService\x12r\n\x03Get\x12\'.yandex.cloud.compute.v1.GetDiskRequest\x1a\x1d.yandex.cloud.compute.v1.Disk\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/compute/v1/disks/{disk_id}\x12x\n\x04List\x12).yandex.cloud.compute.v1.ListDisksRequest\x1a*.yandex.cloud.compute.v1.ListDisksResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/compute/v1/disks\x12\x93\x01\n\x06\x43reate\x12*.yandex.cloud.compute.v1.CreateDiskRequest\x1a!.yandex.cloud.operation.Operation\":\x82\xd3\xe4\x93\x02\x16\"\x11/compute/v1/disks:\x01*\xb2\xd2*\x1a\n\x12\x43reateDiskMetadata\x12\x04\x44isk\x12\x9d\x01\n\x06Update\x12*.yandex.cloud.compute.v1.UpdateDiskRequest\x1a!.yandex.cloud.operation.Operation\"D\x82\xd3\xe4\x93\x02 2\x1b/compute/v1/disks/{disk_id}:\x01*\xb2\xd2*\x1a\n\x12UpdateDiskMetadata\x12\x04\x44isk\x12\xab\x01\n\x06\x44\x65lete\x12*.yandex.cloud.compute.v1.DeleteDiskRequest\x1a!.yandex.cloud.operation.Operation\"R\x82\xd3\xe4\x93\x02\x1d*\x1b/compute/v1/disks/{disk_id}\xb2\xd2*+\n\x12\x44\x65leteDiskMetadata\x12\x15google.protobuf.Empty\x12\xa9\x01\n\x0eListOperations\x12\x32.yandex.cloud.compute.v1.ListDiskOperationsRequest\x1a\x33.yandex.cloud.compute.v1.ListDiskOperationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/compute/v1/disks/{disk_id}/operations\x12\x9c\x01\n\x04Move\x12(.yandex.cloud.compute.v1.MoveDiskRequest\x1a!.yandex.cloud.operation.Operation\"G\x82\xd3\xe4\x93\x02%\" /compute/v1/disks/{disk_id}:move:\x01*\xb2\xd2*\x18\n\x10MoveDiskMetadata\x12\x04\x44iskBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETDISKREQUEST = _descriptor.Descriptor(
  name='GetDiskRequest',
  full_name='yandex.cloud.compute.v1.GetDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.GetDiskRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=323,
)


_LISTDISKSREQUEST = _descriptor.Descriptor(
  name='ListDisksRequest',
  full_name='yandex.cloud.compute.v1.ListDisksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.ListDisksRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListDisksRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListDisksRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListDisksRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=326,
  serialized_end=467,
)


_LISTDISKSRESPONSE = _descriptor.Descriptor(
  name='ListDisksResponse',
  full_name='yandex.cloud.compute.v1.ListDisksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disks', full_name='yandex.cloud.compute.v1.ListDisksResponse.disks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListDisksResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=559,
)


_CREATEDISKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1155,
)

_CREATEDISKREQUEST = _descriptor.Descriptor(
  name='CreateDiskRequest',
  full_name='yandex.cloud.compute.v1.CreateDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.CreateDiskRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.CreateDiskRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.CreateDiskRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.type_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.zone_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.compute.v1.CreateDiskRequest.size', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\372\3071\0264194304-28587302322176', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.image_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_id', full_name='yandex.cloud.compute.v1.CreateDiskRequest.snapshot_id', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_size', full_name='yandex.cloud.compute.v1.CreateDiskRequest.block_size', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_placement_policy', full_name='yandex.cloud.compute.v1.CreateDiskRequest.disk_placement_policy', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEDISKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='yandex.cloud.compute.v1.CreateDiskRequest.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=562,
  serialized_end=1165,
)


_CREATEDISKMETADATA = _descriptor.Descriptor(
  name='CreateDiskMetadata',
  full_name='yandex.cloud.compute.v1.CreateDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.CreateDiskMetadata.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1167,
  serialized_end=1204,
)


_UPDATEDISKREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1110,
  serialized_end=1155,
)

_UPDATEDISKREQUEST = _descriptor.Descriptor(
  name='UpdateDiskRequest',
  full_name='yandex.cloud.compute.v1.UpdateDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.size', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0254194304-4398046511104', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_placement_policy', full_name='yandex.cloud.compute.v1.UpdateDiskRequest.disk_placement_policy', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEDISKREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1207,
  serialized_end=1701,
)


_UPDATEDISKMETADATA = _descriptor.Descriptor(
  name='UpdateDiskMetadata',
  full_name='yandex.cloud.compute.v1.UpdateDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.UpdateDiskMetadata.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1703,
  serialized_end=1740,
)


_DELETEDISKREQUEST = _descriptor.Descriptor(
  name='DeleteDiskRequest',
  full_name='yandex.cloud.compute.v1.DeleteDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.DeleteDiskRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1742,
  serialized_end=1792,
)


_DELETEDISKMETADATA = _descriptor.Descriptor(
  name='DeleteDiskMetadata',
  full_name='yandex.cloud.compute.v1.DeleteDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.DeleteDiskMetadata.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=1831,
)


_LISTDISKOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListDiskOperationsRequest',
  full_name='yandex.cloud.compute.v1.ListDiskOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.ListDiskOperationsRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListDiskOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListDiskOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1833,
  serialized_end=1953,
)


_LISTDISKOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListDiskOperationsResponse',
  full_name='yandex.cloud.compute.v1.ListDiskOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.ListDiskOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListDiskOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1955,
  serialized_end=2063,
)


_MOVEDISKREQUEST = _descriptor.Descriptor(
  name='MoveDiskRequest',
  full_name='yandex.cloud.compute.v1.MoveDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.MoveDiskRequest.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.compute.v1.MoveDiskRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2065,
  serialized_end=2158,
)


_MOVEDISKMETADATA = _descriptor.Descriptor(
  name='MoveDiskMetadata',
  full_name='yandex.cloud.compute.v1.MoveDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.MoveDiskMetadata.disk_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_folder_id', full_name='yandex.cloud.compute.v1.MoveDiskMetadata.source_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.compute.v1.MoveDiskMetadata.destination_folder_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2160,
  serialized_end=2252,
)

_LISTDISKSRESPONSE.fields_by_name['disks'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISK
_CREATEDISKREQUEST_LABELSENTRY.containing_type = _CREATEDISKREQUEST
_CREATEDISKREQUEST.fields_by_name['labels'].message_type = _CREATEDISKREQUEST_LABELSENTRY
_CREATEDISKREQUEST.fields_by_name['disk_placement_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISKPLACEMENTPOLICY
_CREATEDISKREQUEST.oneofs_by_name['source'].fields.append(
  _CREATEDISKREQUEST.fields_by_name['image_id'])
_CREATEDISKREQUEST.fields_by_name['image_id'].containing_oneof = _CREATEDISKREQUEST.oneofs_by_name['source']
_CREATEDISKREQUEST.oneofs_by_name['source'].fields.append(
  _CREATEDISKREQUEST.fields_by_name['snapshot_id'])
_CREATEDISKREQUEST.fields_by_name['snapshot_id'].containing_oneof = _CREATEDISKREQUEST.oneofs_by_name['source']
_UPDATEDISKREQUEST_LABELSENTRY.containing_type = _UPDATEDISKREQUEST
_UPDATEDISKREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEDISKREQUEST.fields_by_name['labels'].message_type = _UPDATEDISKREQUEST_LABELSENTRY
_UPDATEDISKREQUEST.fields_by_name['disk_placement_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISKPLACEMENTPOLICY
_LISTDISKOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetDiskRequest'] = _GETDISKREQUEST
DESCRIPTOR.message_types_by_name['ListDisksRequest'] = _LISTDISKSREQUEST
DESCRIPTOR.message_types_by_name['ListDisksResponse'] = _LISTDISKSRESPONSE
DESCRIPTOR.message_types_by_name['CreateDiskRequest'] = _CREATEDISKREQUEST
DESCRIPTOR.message_types_by_name['CreateDiskMetadata'] = _CREATEDISKMETADATA
DESCRIPTOR.message_types_by_name['UpdateDiskRequest'] = _UPDATEDISKREQUEST
DESCRIPTOR.message_types_by_name['UpdateDiskMetadata'] = _UPDATEDISKMETADATA
DESCRIPTOR.message_types_by_name['DeleteDiskRequest'] = _DELETEDISKREQUEST
DESCRIPTOR.message_types_by_name['DeleteDiskMetadata'] = _DELETEDISKMETADATA
DESCRIPTOR.message_types_by_name['ListDiskOperationsRequest'] = _LISTDISKOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListDiskOperationsResponse'] = _LISTDISKOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['MoveDiskRequest'] = _MOVEDISKREQUEST
DESCRIPTOR.message_types_by_name['MoveDiskMetadata'] = _MOVEDISKMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetDiskRequest = _reflection.GeneratedProtocolMessageType('GetDiskRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetDiskRequest)
  })
_sym_db.RegisterMessage(GetDiskRequest)

ListDisksRequest = _reflection.GeneratedProtocolMessageType('ListDisksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISKSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListDisksRequest)
  })
_sym_db.RegisterMessage(ListDisksRequest)

ListDisksResponse = _reflection.GeneratedProtocolMessageType('ListDisksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISKSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListDisksResponse)
  })
_sym_db.RegisterMessage(ListDisksResponse)

CreateDiskRequest = _reflection.GeneratedProtocolMessageType('CreateDiskRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDISKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateDiskRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateDiskRequest)
  })
_sym_db.RegisterMessage(CreateDiskRequest)
_sym_db.RegisterMessage(CreateDiskRequest.LabelsEntry)

CreateDiskMetadata = _reflection.GeneratedProtocolMessageType('CreateDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateDiskMetadata)
  })
_sym_db.RegisterMessage(CreateDiskMetadata)

UpdateDiskRequest = _reflection.GeneratedProtocolMessageType('UpdateDiskRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEDISKREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateDiskRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateDiskRequest)
  })
_sym_db.RegisterMessage(UpdateDiskRequest)
_sym_db.RegisterMessage(UpdateDiskRequest.LabelsEntry)

UpdateDiskMetadata = _reflection.GeneratedProtocolMessageType('UpdateDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateDiskMetadata)
  })
_sym_db.RegisterMessage(UpdateDiskMetadata)

DeleteDiskRequest = _reflection.GeneratedProtocolMessageType('DeleteDiskRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteDiskRequest)
  })
_sym_db.RegisterMessage(DeleteDiskRequest)

DeleteDiskMetadata = _reflection.GeneratedProtocolMessageType('DeleteDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteDiskMetadata)
  })
_sym_db.RegisterMessage(DeleteDiskMetadata)

ListDiskOperationsRequest = _reflection.GeneratedProtocolMessageType('ListDiskOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISKOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListDiskOperationsRequest)
  })
_sym_db.RegisterMessage(ListDiskOperationsRequest)

ListDiskOperationsResponse = _reflection.GeneratedProtocolMessageType('ListDiskOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDISKOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListDiskOperationsResponse)
  })
_sym_db.RegisterMessage(ListDiskOperationsResponse)

MoveDiskRequest = _reflection.GeneratedProtocolMessageType('MoveDiskRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.MoveDiskRequest)
  })
_sym_db.RegisterMessage(MoveDiskRequest)

MoveDiskMetadata = _reflection.GeneratedProtocolMessageType('MoveDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.disk_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.MoveDiskMetadata)
  })
_sym_db.RegisterMessage(MoveDiskMetadata)


DESCRIPTOR._options = None
_GETDISKREQUEST.fields_by_name['disk_id']._options = None
_LISTDISKSREQUEST.fields_by_name['folder_id']._options = None
_LISTDISKSREQUEST.fields_by_name['page_size']._options = None
_LISTDISKSREQUEST.fields_by_name['page_token']._options = None
_LISTDISKSREQUEST.fields_by_name['filter']._options = None
_CREATEDISKREQUEST_LABELSENTRY._options = None
_CREATEDISKREQUEST.fields_by_name['folder_id']._options = None
_CREATEDISKREQUEST.fields_by_name['name']._options = None
_CREATEDISKREQUEST.fields_by_name['description']._options = None
_CREATEDISKREQUEST.fields_by_name['labels']._options = None
_CREATEDISKREQUEST.fields_by_name['type_id']._options = None
_CREATEDISKREQUEST.fields_by_name['zone_id']._options = None
_CREATEDISKREQUEST.fields_by_name['size']._options = None
_CREATEDISKREQUEST.fields_by_name['image_id']._options = None
_CREATEDISKREQUEST.fields_by_name['snapshot_id']._options = None
_UPDATEDISKREQUEST_LABELSENTRY._options = None
_UPDATEDISKREQUEST.fields_by_name['disk_id']._options = None
_UPDATEDISKREQUEST.fields_by_name['name']._options = None
_UPDATEDISKREQUEST.fields_by_name['description']._options = None
_UPDATEDISKREQUEST.fields_by_name['labels']._options = None
_UPDATEDISKREQUEST.fields_by_name['size']._options = None
_DELETEDISKREQUEST.fields_by_name['disk_id']._options = None
_LISTDISKOPERATIONSREQUEST.fields_by_name['disk_id']._options = None
_LISTDISKOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTDISKOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_MOVEDISKREQUEST.fields_by_name['disk_id']._options = None
_MOVEDISKREQUEST.fields_by_name['destination_folder_id']._options = None

_DISKSERVICE = _descriptor.ServiceDescriptor(
  name='DiskService',
  full_name='yandex.cloud.compute.v1.DiskService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2255,
  serialized_end=3321,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.DiskService.Get',
    index=0,
    containing_service=None,
    input_type=_GETDISKREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISK,
    serialized_options=b'\202\323\344\223\002\035\022\033/compute/v1/disks/{disk_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.DiskService.List',
    index=1,
    containing_service=None,
    input_type=_LISTDISKSREQUEST,
    output_type=_LISTDISKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/compute/v1/disks',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.DiskService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\026\"\021/compute/v1/disks:\001*\262\322*\032\n\022CreateDiskMetadata\022\004Disk',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.DiskService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002 2\033/compute/v1/disks/{disk_id}:\001*\262\322*\032\n\022UpdateDiskMetadata\022\004Disk',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.DiskService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\035*\033/compute/v1/disks/{disk_id}\262\322*+\n\022DeleteDiskMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.DiskService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTDISKOPERATIONSREQUEST,
    output_type=_LISTDISKOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/compute/v1/disks/{disk_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.compute.v1.DiskService.Move',
    index=6,
    containing_service=None,
    input_type=_MOVEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002%\" /compute/v1/disks/{disk_id}:move:\001*\262\322*\030\n\020MoveDiskMetadata\022\004Disk',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DISKSERVICE)

DESCRIPTOR.services_by_name['DiskService'] = _DISKSERVICE

# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python3
import argparse
import json
import os
import logging
import uuid

import yandexcloud
from yandexcloud.operations import OperationError

USER_AGENT = 'ycloud-python-sdk:dataproc.example.using_wrapper'


def main():
    logging.basicConfig(level=logging.INFO)
    arguments = parse_cmd()
    if arguments.token:
        sdk = yandexcloud.SDK(token=arguments.token, user_agent=USER_AGENT)
    else:
        with open(arguments.sa_json_path) as infile:
            sdk = yandexcloud.SDK(service_account_key=json.load(infile), user_agent=USER_AGENT)
    fill_missing_arguments(sdk, arguments)

    dataproc = sdk.wrappers.Dataproc(
        default_folder_id=arguments.folder_id,
        default_public_ssh_key=arguments.ssh_public_key,
    )
    bucket_for_logs_output = arguments.s3_bucket
    services = (
        'HDFS',
        'YARN',
        'MAPREDUCE',
        'HIVE',
        'SPARK',
    )
    try:
        dataproc.create_cluster(
            masternode_resource_preset='s2.micro',
            datanode_count=2,
            datanode_resource_preset='s2.micro',
            subnet_id=arguments.subnet_id,
            s3_bucket=bucket_for_logs_output,
            service_account_id=arguments.service_account_id,
            zone=arguments.zone,
            services=services,
            log_group_id=arguments.log_group_id,
        )

        dataproc.update_cluster_description('New cluster description')

        dataproc.create_subcluster(
            subcluster_type='compute',
            name='compute',
            hosts_count=1,
            resource_preset='s2.micro',
            max_hosts_count=2,
            cpu_utilization_target=66,
            preemptible=True,
        )

        dataproc.create_mapreduce_job(
            main_class='org.apache.hadoop.streaming.HadoopStreaming',
            file_uris=[
                's3a://data-proc-public/jobs/sources/mapreduce-001/mapper.py',
                's3a://data-proc-public/jobs/sources/mapreduce-001/reducer.py'
            ],
            args=[
                '-mapper', 'mapper.py',
                '-reducer', 'reducer.py',
                '-numReduceTasks', '1',
                '-input', 's3a://data-proc-public/jobs/sources/data/cities500.txt.bz2',
                '-output', 's3a://{bucket}/dataproc/job/results/{uuid}'.format(bucket=bucket_for_logs_output, uuid=uuid.uuid4())
            ],
            properties={
                'yarn.app.mapreduce.am.resource.mb': '2048',
                'yarn.app.mapreduce.am.command-opts': '-Xmx2048m',
                'mapreduce.job.maps': '6',
            },
        )

        dataproc.create_hive_job(
            query_file_uri='s3a://data-proc-public/jobs/sources/hive-001/main.sql',
            script_variables={
                'CITIES_URI': 's3a://data-proc-public/jobs/sources/hive-001/cities/',
                'COUNTRY_CODE': 'RU',
            }
        )

        dataproc.create_spark_job(
            name='Spark job: Find total urban population in distribution by country',
            main_jar_file_uri='s3a://data-proc-public/jobs/sources/java/dataproc-examples-1.0.jar',
            main_class='ru.yandex.cloud.dataproc.examples.PopulationSparkJob',
            file_uris=[
                's3a://data-proc-public/jobs/sources/data/config.json',
            ],
            archive_uris=[
                's3a://data-proc-public/jobs/sources/data/country-codes.csv.zip',
            ],
            jar_file_uris=[
                's3a://data-proc-public/jobs/sources/java/icu4j-61.1.jar',
                's3a://data-proc-public/jobs/sources/java/commons-lang-2.6.jar',
                's3a://data-proc-public/jobs/sources/java/opencsv-4.1.jar',
                's3a://data-proc-public/jobs/sources/java/json-20190722.jar'
            ],
            args=[
                's3a://data-proc-public/jobs/sources/data/cities500.txt.bz2',
                's3a://{bucket}/dataproc/job/results/${{JOB_ID}}'.format(bucket=bucket_for_logs_output),
            ],
            properties={
                'spark.submit.deployMode': 'cluster',
            },
            packages=['org.slf4j:slf4j-simple:1.7.30'],
            repositories=['https://repo1.maven.org/maven2'],
            exclude_packages=['com.amazonaws:amazon-kinesis-client'],
        )

        dataproc.create_pyspark_job(
            main_python_file_uri='s3a://data-proc-public/jobs/sources/pyspark-001/main.py',
            python_file_uris=[
                's3a://data-proc-public/jobs/sources/pyspark-001/geonames.py',
            ],
            file_uris=[
                's3a://data-proc-public/jobs/sources/data/config.json',
            ],
            archive_uris=[
                's3a://data-proc-public/jobs/sources/data/country-codes.csv.zip',
            ],
            args=[
                's3a://data-proc-public/jobs/sources/data/cities500.txt.bz2',
                's3a://{bucket}/jobs/results/${{JOB_ID}}'.format(bucket=bucket_for_logs_output),
            ],
            jar_file_uris=[
                's3a://data-proc-public/jobs/sources/java/dataproc-examples-1.0.jar',
                's3a://data-proc-public/jobs/sources/java/icu4j-61.1.jar',
                's3a://data-proc-public/jobs/sources/java/commons-lang-2.6.jar',
            ],
            properties={
                'spark.submit.deployMode': 'cluster',
            },
            packages=['org.slf4j:slf4j-simple:1.7.30'],
            repositories=['https://repo1.maven.org/maven2'],
            exclude_packages=['com.amazonaws:amazon-kinesis-client'],
        )

    except OperationError:
        logging.exception('Operation error:')

    finally:
        if dataproc.cluster_id is not None:
            dataproc.delete_cluster()


def parse_cmd():
    parser = argparse.ArgumentParser(
        description=__doc__,
        formatter_class=argparse.RawTextHelpFormatter)

    auth = parser.add_mutually_exclusive_group(required=True)
    auth.add_argument(
        '--sa-json-path',
        help='Path to the service account key JSON file.\nThis file can be created using YC CLI:\n'
        'yc iam key create --output sa.json --service-account-id <id>',
    )
    auth.add_argument('--token', help='OAuth token')
    parser.add_argument('--folder-id', help='Your Yandex.Cloud folder id', required=True)
    parser.add_argument('--zone', default='ru-central1-b', help='Compute Engine zone to deploy to')
    parser.add_argument('--network-id', default='', help='Your Yandex.Cloud network id')
    parser.add_argument('--subnet-id', default='', help='Subnet for the cluster')
    parser.add_argument('--cluster-name', default='cluster1', help='New cluster name')
    parser.add_argument('--cluster-desc', default='', help='New cluster description')
    parser.add_argument(
        '--ssh-public-key',
        default='ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAII7JOBFU5LGCd/ET220neX7MiWIXHnZI9ZfFjjgnPMmh'
    )
    parser.add_argument('--service-account-id', default='')
    parser.add_argument('--log-group-id', default=None)
    parser.add_argument('--s3-bucket', required=True)
    return parser.parse_args()


def fill_missing_arguments(sdk, arguments):
    if os.path.exists(os.path.expanduser(arguments.ssh_public_key)):
        with open(arguments.ssh_public_key) as infile:
            arguments.ssh_public_key = infile.read().strip()

    if not arguments.network_id:
        arguments.network_id = sdk.helpers.find_network_id(folder_id=arguments.folder_id)

    if not arguments.subnet_id:
        arguments.subnet_id = sdk.helpers.find_subnet_id(
            folder_id=arguments.folder_id,
            zone_id=arguments.zone,
            network_id=arguments.network_id
        )

    if not arguments.service_account_id:
        arguments.service_account_id = sdk.helpers.find_service_account_id(folder_id=arguments.folder_id)


if __name__ == '__main__':
    main()



import pytest


@pytest.fixture()
def token():
    return "AAAA00000000000000000000000000000000000"


@pytest.fixture()
def iam_token():
    return "xxxxxx"


@pytest.fixture()
def service_account_key():
    return {
        "id": "ajeboa0du6edu6m43c3t",
        "service_account_id": "ajeq7dsmihqple6761c5",
        "created_at": "2018-10-31T09:30:52Z",
        "key_algorithm": "RSA_4096",
        "public_key": "-----BEGIN PUBLIC KEY-----\nMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEA0q4HXY6/7jzA3iwofyTq\nxJ+VPR2fQGrhd+nEi32lemw8XEqVpr4wvzaJHdW2921Z7nsEKJPJq9ZCaDpnkdpS\npGPnJCUtJSYQvjs5yrYbEB00LGGi4pERDNWbsX+MyyMl+0Mqd3G3wiu/T8k31T5F\ngmOK1KPnlDQ6JjZ+OQWkBojBTGGkaCsYKuDwuKfsHZQCqhTt8pLIN7ZiiXWRIB4Q\n4GfBuBWUfhgncbNCj+PBEBvy1auFnI0CHQ8T9cHqnh9UQIi0qsxVslICv4Z5iX4y\nYCrRfSw3UJOqQ+mkttSNBjnJC7TpC4uQyc98XC+kLzP1i8/nNv967K9eWA6MVsHF\nZqAkFJYcUn6Bx/f3FDiIcW0tR5P/FgDtVTvQAAdUW+l02P27JOqRyD9oDX/y889/\nc1TGbXlhmaWCqjIVoUnUBlnlHAB7v8X4aqlCu9vwP0DUaXdI/Yxf7VcG6B7wFFZN\noM2k6X1J3LSMdrFTXSLbduv/n0mMLUurUx1D0YIIrk2Kv1N63YNiVtPWdFkGHQs6\nshVgrpiTBUm0VBME7EYKwKQUK7pZ0gn6/IeZpgel0aPCQtaF9FIffLi8KJaMVbJi\nNGgvr4HTejzn/jabWuLc3rN62AexNYUqnRMfmfNPXyArJ0A54tl2u/TKoPmw0w5t\nYAwgJ+mSGlylBJbZy2CBp2sCAwEAAQ==\n-----END PUBLIC KEY-----\n",
        "private_key": "-----BEGIN PRIVATE KEY-----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\nawxDbYxnTunk1YxP7KA0/bDnu/OZlQ==\n-----END PRIVATE KEY-----\n"
    }



#!/usr/bin/env python3
import argparse
import json
import logging

from google.protobuf.field_mask_pb2 import FieldMask

import yandex.cloud.mdb.redis.v1.cluster_pb2 as cluster_pb
import yandex.cloud.mdb.redis.v1.config.redis5_0_pb2 as redis5_0_pb2
import yandex.cloud.mdb.redis.v1.cluster_service_pb2 as cluster_service
import yandex.cloud.mdb.redis.v1.cluster_service_pb2_grpc as cluster_service_grpc

import yandexcloud


def main():
    logging.basicConfig(level=logging.INFO)
    arguments = parse_cmd()
    if arguments.token:
        sdk = yandexcloud.SDK(token=arguments.token)
    else:
        with open(arguments.sa_json_path) as infile:
            sdk = yandexcloud.SDK(service_account_key=json.load(infile))

    fill_missing_arguments(sdk, arguments)

    cluster_id = None
    try:
        operation_result = create_cluster(sdk, create_cluster_request(arguments))
        cluster_id = operation_result.response.id
        change_cluster_description(sdk, cluster_id)
        add_cluster_host(sdk, cluster_id, arguments)
    finally:
        if cluster_id is not None:
            delete_cluster(sdk, cluster_id)


def parse_cmd():
    parser = argparse.ArgumentParser(
        description=__doc__,
        formatter_class=argparse.RawTextHelpFormatter)
    auth = parser.add_mutually_exclusive_group(required=True)
    auth.add_argument(
        '--sa-json-path',
        help='Path to the service account key JSON file.\nThis file can be created using YC CLI:\n'
        'yc iam key create --output sa.json --service-account-id <id>',
    )
    auth.add_argument('--token', help='OAuth token')
    parser.add_argument('--folder-id', help='Your Yandex.Cloud folder id', required=True)
    parser.add_argument('--zone', default='ru-central1-b', help='Compute Engine zone to deploy to')
    parser.add_argument('--network-id', default='', help='Your Yandex.Cloud network id')
    parser.add_argument('--subnet-id', default='', help='Subnet for the cluster')
    parser.add_argument('--cluster-name', default='cluster1', help='New cluster name')
    parser.add_argument('--cluster-desc', default='', help='New cluster description')
    parser.add_argument('--password', default='password123')
    return parser.parse_args()


def fill_missing_arguments(sdk, arguments):
    if not arguments.network_id:
        arguments.network_id = sdk.helpers.find_network_id(folder_id=arguments.folder_id)

    if not arguments.subnet_id:
        arguments.subnet_id = sdk.helpers.find_subnet_id(
            folder_id=arguments.folder_id,
            zone_id=arguments.zone,
            network_id=arguments.network_id,
        )


def create_cluster(sdk, request):
    operation = sdk.client(cluster_service_grpc.ClusterServiceStub).Create(request)
    return sdk.wait_operation_and_get_result(
        operation,
        response_type=cluster_pb.Cluster,
        meta_type=cluster_service.CreateClusterMetadata,
    )


def add_cluster_host(sdk, cluster_id, params):
    logging.info('Adding host to cluster {}'.format(cluster_id))

    host_specs = [cluster_service.HostSpec(zone_id=params.zone, subnet_id=params.subnet_id)]
    request = cluster_service.AddClusterHostsRequest(cluster_id=cluster_id, host_specs=host_specs)

    operation = sdk.client(cluster_service_grpc.ClusterServiceStub).AddHosts(request)
    return sdk.wait_operation_and_get_result(
        operation,
        meta_type=cluster_service.AddClusterHostsMetadata,
    )


def change_cluster_description(sdk, cluster_id):
    logging.info('Updating cluster {}'.format(cluster_id))
    mask = FieldMask(paths=['description'])
    request = cluster_service.UpdateClusterRequest(
        cluster_id=cluster_id, update_mask=mask,
        description='New Description',
    )

    operation = sdk.client(cluster_service_grpc.ClusterServiceStub).Update(request)
    return sdk.wait_operation_and_get_result(
        operation,
        response_type=cluster_pb.Cluster,
        meta_type=cluster_service.UpdateClusterMetadata,
    )


def delete_cluster(sdk, cluster_id):
    logging.info('Deleting cluster {}'.format(cluster_id))
    operation = sdk.client(cluster_service_grpc.ClusterServiceStub).Delete(
        cluster_service.DeleteClusterRequest(cluster_id=cluster_id))
    return sdk.wait_operation_and_get_result(
        operation,
        meta_type=cluster_service.DeleteClusterMetadata,
    )


def create_cluster_request(params):
    host_specs = [cluster_service.HostSpec(zone_id=params.zone, subnet_id=params.subnet_id)]
    res = cluster_pb.Resources(resource_preset_id='hm1.nano', disk_size=16 * (1024 ** 3))

    config_spec = cluster_service.ConfigSpec(
        version='5.0',
        redis_config_5_0=redis5_0_pb2.RedisConfig5_0(
            maxmemory_policy='MAXMEMORY_POLICY_UNSPECIFIED',
            password=params.password,
        ),
        resources=res,
        access=cluster_pb.Access(data_lens=False),
    )

    return cluster_service.CreateClusterRequest(
        folder_id=params.folder_id,
        name=params.cluster_name,
        description=params.cluster_desc,
        environment='PRODUCTION',
        config_spec=config_spec,
        host_specs=host_specs,
        network_id=params.network_id,
        sharded=False,
    )


if __name__ == '__main__':
    main()
